==> thc-ipv6_3.0.orig.tar.gz: thc-ipv6-3.0/fps.h <==
/*
    Copyright (c) warlord @ nologin.org.  All rights reserved.
    For more information, please visit http://www.nologin.org
 */

static struct fingerprints {
  char *fingerprint;
  char *OS;
}

fingerprintsArray[] = {
{"0028:50:0100", "Dell Switch"},
{"0028:50:0200", "Dell Switch"},
{"0028:50:0218", "Packeteer PacketShaper"},
{"0028:50:0800", "Livingston Portmaster|Dell Switch"},
{"0028:50:1000", "Cabletron Switch"},
{"0028:50:2000", "NetBotz Network Monitoring Appliance"},
{"0028:50:ffff", "Netscreen Firewall"},
{"002c:60:1020:SS0204", "Cisco IOS (e.g. Switch ME2600)"},
{"002c:60:16d0:SS05b4", "Solaris v?"},
{"002c:60:2000:SS0200", "Huawei MA5600"},
{"002c:60:2000:SS0564", "Windows 2003 Server"},
{"002c:60:5000:SS0578", "Astoria Networks DSL Modem"},
{"002c:60:5b40:SS0218", "Polycom ViewStation FX MP"},
{"002c:60:faf0:SS05b4", "Linux 3.2.x - 3.4.x | Playstation 4"},
{"002c:60:1020:SS05a0", "Cisco Catalyst 4xxx"},
{"0030:70:2238:SS05b4:NOP:NOP:SP", "Windows 98"},
{"0030:70:4000:SS05a0:WSxx", "Cisco ASR"},
{"0030:70:ffff:SS059c:SP", "Centos v?"},
{"0034:80:3908:SS0578:NOP:NOP:SP:NOP:WSxx", "QVIS DVR"},
{"0038:90:16a0:SS0564:SP:TS", "Mac OS X Server v? | Linux v?"},
{"0038:90:2000:SS0564:SP:TS", "Windows Server 2008 R2 | Windows 7"},
{"0038:90:2000:SS05b4:SP:TS", "Windows Vista | Windows Server 2008"},
{"003c:a0:102c:SS0564:NOP:NOP:TS:SP", "F5 BigIP"},
{"003c:a0:1640:SS059c:SP:TS:NOP:WSxx", "Metaswitch Perimeta Session Border Controller"},
{"003c:a0:1650:SS05a0:SP:TS:NOP:WSxx", "Linux 2.6.x"}, 
{"003c:a0:1680:SS05ac:SP:TS:NOP:WSxx", "Broadband RouterLLLL"},
{"003c:a0:16a0:SS05ac:SP:TS:NOP:WSxx", "Mikrotik Router"},
{"003c:a0:16a0:SS05b4:SP:TS:NOP:WSxx", "Solaris 8 | NetBSD v? | Linux v?"},
{"003c:a0:2000:SS0400:NOP:WSxx:NOP:NOP:TS", "Alcatel TiMOS Router"},
{"002c:60:2000:SS0400", "Alcatel TiMOS Router"},
{"002c:60:8000:SS0400", "Alcatel TiMOS Router"},
{"003c:a0:2000:SS05a0:NOP:WSxx:SP:TS", "Windows 7"},
{"003c:a0:2000:SS05b4:NOP:WSxx:SP:TS", "Windows Vista | Windows 7 | Windows 8 | Windows Server 2008 | Windows 2012 Server"},
{"003c:a0:37c8:SS05a0:SP:TS:NOP:WSxx", "Linux 3.2.x"},
{"003c:a0:3890:SS0514:SP:TS:NOP:WSxx", "Centos v?"},
{"003c:a0:3890:SS05b4:SP:TS:NOP:WSxx", "Linux v? | ?Loadbalancer/Cloud?"},
{"003c:a0:4380:SS05ac:NOP:WSxx:NOP:NOP:TS", "Motorola Residential Gateway"},
{"003c:a0:4750:SS05a0:SP:TS:NOP:WSxx", "A10 Networks Appliance"},
{"003c:a0:6f90:SS05a0:SP:TS:NOP:WSxx", "Linux 3.12+"},
{"003c:a0:8000:SS0400:NOP:WSxx:NOP:NOP:TS", "Alcatel TiMOS Router"},
{"003c:a0:8000:SS400c:SP:TS:NOP:WSxx", "Linux 3.2.x Ubuntu"},
{"003c:a0:ffff:SS05a0:NOP:WSxx:SP:TS", "FreeBSD 8.1"},
{"003c:a0:ffff:SS05b4:NOP:WSxx:SP:TS", "FreeBSD v?"},
{"0040:b0:4000:SS05b4:NOP:WSxx:NOP:NOP:TS:NOP:NOP:SP", "Windows 2003 Server"},
{"0040:b0:8000:SS0564:NOP:NOP:SP:WSxx:NOP:NOP:NOP:TS", "HP-UX v?"},
{"0040:b0:8000:SS05a0:NOP:WSxx:NOP:NOP:TS:SP:NOP:NOP", "NetBSD v?"},
{"0040:b0:8000:SS05b4:NOP:NOP:SP:WSxx:NOP:NOP:NOP:TS", "HP-UX v?"},
{"0040:b0:8026:NOP:NOP:TS:SS05b4:NOP:WSxx:NOP:NOP:SP", "Solaris v?"},
{"0040:b0:faf0:SS05b4:NOP:WSxx:NOP:NOP:TS:NOP:NOP:SP", "Windows XP SP3|Windows 2000 Server|Windows Server 2003"},
{"0040:b0:fffd:SS05a0:NOP:WS02:NOP:NOP:TS:SP:UOP:UOP", "F5"},
{"0040:b0:fffd:SS05a0:NOP:WSxx:NOP:NOP:TS:SP:UOP:UOP", "F5 BigIP"},
{"0040:b0:fffd:SS05b4:NOP:WSxx:NOP:NOP:TS:SP", "Windows Server 2008 R2 | Windows 7 | Redhat v?"},
{"0040:b0:ffff:SS05b4:NOP:WSxx:NOP:NOP:TS:SP", "Mac OS X Server v?"},
{"0040:b0:ffff:SS05a0:NOP:WSxx:NOP:NOP:TS:SP", "Mac OS X Maverick"},
};

==> thc-ipv6_3.6.orig.tar.gz: thc-ipv6-3.6/fps.h <==
/*
    Copyright (c) warlord @ nologin.org.  All rights reserved.
    For more information, please visit http://www.nologin.org
 */

static struct fingerprints {
  char *fingerprint;
  char *OS;
}

fingerprintsArray[] = {
{"0040:b0:ffff:SS05a0:NOP:WSxx:NOP:NOP:TS:SP:NOP:NOP", "QNX 6.x"},
{"002c:60:16d0:SS059c", "LWP embedded TCP/IP stack"},
{"003c:a0:4000:SS05a0:NOP:WSxx:SP:TS", "Ironport"},
{"0028:50:0100", "Dell Switch"},
{"0028:50:0200", "Dell Switch"},
{"0028:50:0218", "Packeteer PacketShaper"},
{"0028:50:0800", "Livingston Portmaster|Dell Switch"},
{"0028:50:1000", "Cabletron Switch"},
{"0028:50:2000", "NetBotz Network Monitoring Appliance"},
{"0028:50:ffff", "Netscreen Firewall"},
{"002c:60:1020:SS0204", "Cisco IOS (e.g. Switch ME2600)"},
{"002c:60:16d0:SS05b4", "Solaris v?"},
{"002c:60:2000:SS0200", "Huawei MA5600"},
{"002c:60:2000:SS0564", "Windows 2003 Server"},
{"002c:60:5000:SS0578", "Astoria Networks DSL Modem"},
{"002c:60:5b40:SS0218", "Polycom ViewStation FX MP"},
{"002c:60:faf0:SS05b4", "Linux 3.2.x - 3.4.x | Playstation 4"},
{"002c:60:1020:SS05a0", "Cisco Catalyst 4xxx"},
{"0030:70:2238:SS05b4:NOP:NOP:SP", "Windows 98"},
{"0030:70:4000:SS05a0:WSxx", "Cisco ASR"},
{"0030:70:ffff:SS059c:SP", "Centos v?"},
{"0034:80:3908:SS0578:NOP:NOP:SP:NOP:WSxx", "QVIS DVR"},
{"0038:90:16a0:SS0564:SP:TS", "Mac OS X Server v? | Linux v?"},
{"0038:90:2000:SS0564:SP:TS", "Windows Server 2008 R2 | Windows 7"},
{"0038:90:2000:SS05b4:SP:TS", "Windows Vista | Windows Server 2008"},
{"003c:a0:102c:SS0564:NOP:NOP:TS:SP", "F5 BigIP"},
{"003c:a0:1640:SS059c:SP:TS:NOP:WSxx", "Metaswitch Perimeta Session Border Controller"},
{"003c:a0:1650:SS05a0:SP:TS:NOP:WSxx", "Linux 2.6.x"}, 
{"003c:a0:1680:SS05ac:SP:TS:NOP:WSxx", "Broadband RouterLLLL"},
{"003c:a0:16a0:SS05ac:SP:TS:NOP:WSxx", "Mikrotik Router"},
{"003c:a0:16a0:SS05b4:SP:TS:NOP:WSxx", "Solaris 8 | NetBSD v? | Linux v?"},
{"003c:a0:2000:SS0400:NOP:WSxx:NOP:NOP:TS", "Alcatel TiMOS Router"},
{"002c:60:2000:SS0400", "Alcatel TiMOS Router"},
{"002c:60:8000:SS0400", "Alcatel TiMOS Router"},
{"003c:a0:2000:SS05a0:NOP:WSxx:SP:TS", "Windows 7"},
{"003c:a0:2000:SS05b4:NOP:WSxx:SP:TS", "Windows Vista | Windows 7 | Windows 8 | Windows Server 2008 | Windows 2012 Server"},
{"003c:a0:37c8:SS05a0:SP:TS:NOP:WSxx", "Linux 3.2.x"},
{"003c:a0:3890:SS0514:SP:TS:NOP:WSxx", "Centos v?"},
{"003c:a0:3890:SS05b4:SP:TS:NOP:WSxx", "Linux v? | ?Loadbalancer/Cloud?"},
{"003c:a0:4380:SS05ac:NOP:WSxx:NOP:NOP:TS", "Motorola Residential Gateway"},
{"003c:a0:4750:SS05a0:SP:TS:NOP:WSxx", "A10 Networks Appliance"},
{"003c:a0:6f90:SS05a0:SP:TS:NOP:WSxx", "Linux 3.12+"},
{"003c:a0:8000:SS0400:NOP:WSxx:NOP:NOP:TS", "Alcatel TiMOS Router"},
{"003c:a0:8000:SS400c:SP:TS:NOP:WSxx", "Linux 3.2.x Ubuntu"},
{"003c:a0:ffff:SS05a0:NOP:WSxx:SP:TS", "FreeBSD 8.1"},
{"003c:a0:ffff:SS05b4:NOP:WSxx:SP:TS", "FreeBSD v?"},
{"0040:b0:4000:SS05b4:NOP:WSxx:NOP:NOP:TS:NOP:NOP:SP", "Windows 2003 Server"},
{"0040:b0:8000:SS0564:NOP:NOP:SP:WSxx:NOP:NOP:NOP:TS", "HP-UX v?"},
{"0040:b0:8000:SS05a0:NOP:WSxx:NOP:NOP:TS:SP:NOP:NOP", "NetBSD v?"},
{"0040:b0:8000:SS05b4:NOP:NOP:SP:WSxx:NOP:NOP:NOP:TS", "HP-UX v?"},
{"0040:b0:8026:NOP:NOP:TS:SS05b4:NOP:WSxx:NOP:NOP:SP", "Solaris v?"},
{"0040:b0:faf0:SS05b4:NOP:WSxx:NOP:NOP:TS:NOP:NOP:SP", "Windows XP SP3|Windows 2000 Server|Windows Server 2003"},
{"0040:b0:fffd:SS05a0:NOP:WS02:NOP:NOP:TS:SP:UOP:UOP", "F5"},
{"0040:b0:fffd:SS05a0:NOP:WSxx:NOP:NOP:TS:SP:UOP:UOP", "F5 BigIP"},
{"0040:b0:fffd:SS05b4:NOP:WSxx:NOP:NOP:TS:SP", "Windows Server 2008 R2 | Windows 7 | Redhat v?"},
{"0040:b0:ffff:SS05b4:NOP:WSxx:NOP:NOP:TS:SP", "Mac OS X Server v?"},
{"0040:b0:ffff:SS05a0:NOP:WSxx:NOP:NOP:TS:SP", "Mac OS X Maverick"},
};
